@@ -223,7 +223,7 @@
 //!
 //! ```toml
 //! [dependencies]
-//! revai = "0.2.1"
+//! revai = "0.2.2"
 //! ```
 //!
 //! ## Basic example
@@ -386,10 +386,13 @@ impl Client {
         }
 
         if let Some(body) = body {
-            //println!("Body: {:?}", String::from_utf8(body.as_bytes().unwrap().to_vec()).unwrap());
+            log::debug!(
+                "body: {:?}",
+                String::from_utf8(body.as_bytes().unwrap().to_vec()).unwrap()
+            );
             req = req.body(body);
         }
-        //println!("Request: {:?}", &req);
+        log::debug!("request: {:?}", &req);
         Ok(req.send().await?)
     }
 
@@ -409,7 +412,10 @@ impl Client {
         let response_body = response.bytes().await?;
 
         if status.is_success() {
-            //println!("response payload {}", String::from_utf8_lossy(&response_body));
+            log::debug!(
+                "response payload {}",
+                String::from_utf8_lossy(&response_body)
+            );
             let parsed_response = if status == http::StatusCode::NO_CONTENT
                 || std::any::TypeId::of::<Out>() == std::any::TypeId::of::<()>()
             {
@@ -419,11 +425,6 @@ impl Client {
             };
             parsed_response.map_err(Error::from)
         } else {
-            /*println!("error status: {:?}, response payload: {}",
-                status,
-                String::from_utf8_lossy(&response_body),
-            );*/
-
             let error = if response_body.is_empty() {
                 anyhow!("code: {}, empty response", status)
             } else {
@@ -459,7 +460,10 @@ impl Client {
         let response_body = response.bytes().await?;
 
         if status.is_success() {
-            //println!("response payload {}", String::from_utf8_lossy(&response_body));
+            log::debug!(
+                "response payload {}",
+                String::from_utf8_lossy(&response_body)
+            );
 
             let parsed_response = if status == http::StatusCode::NO_CONTENT
                 || std::any::TypeId::of::<Out>() == std::any::TypeId::of::<()>()
@@ -470,10 +474,6 @@ impl Client {
             };
             parsed_response.map(|out| (link, out)).map_err(Error::from)
         } else {
-            /*println!("error status: {:?}, response payload: {}",
-                status,
-                String::from_utf8_lossy(&response_body),
-            );*/
             let error = if response_body.is_empty() {
                 anyhow!("code: {}, empty response", status)
             } else {
@@ -518,9 +518,10 @@ impl Client {
             req = req.header(http::header::AUTHORIZATION, &*auth_str);
         }
 
+        log::debug!("form: {:?}", form);
         req = req.multipart(form);
 
-        //println!("Request: {:?}", &req);
+        log::debug!("request: {:?}", &req);
         let response = req.send().await?;
 
         let status = response.status();
@@ -528,7 +529,10 @@ impl Client {
         let response_body = response.bytes().await?;
 
         if status.is_success() {
-            //println!("response payload {}", String::from_utf8_lossy(&response_body));
+            log::debug!(
+                "response payload {}",
+                String::from_utf8_lossy(&response_body)
+            );
             let parsed_response = if status == http::StatusCode::NO_CONTENT
                 || std::any::TypeId::of::<Out>() == std::any::TypeId::of::<()>()
             {
@@ -543,11 +547,6 @@ impl Client {
             };
             parsed_response.map_err(Error::from)
         } else {
-            /*println!("error status: {:?}, response payload: {}",
-                status,
-                String::from_utf8_lossy(&response_body),
-            );*/
-
             let error = if response_body.is_empty() {
                 anyhow!("code: {}, empty response", status)
             } else {
@@ -594,7 +593,7 @@ impl Client {
             req = req.header(http::header::AUTHORIZATION, &*auth_str);
         }
 
-        //println!("Request: {:?}", &req);
+        log::debug!("request: {:?}", &req);
         let response = req.send().await?;
 
         let status = response.status();
@@ -602,7 +601,10 @@ impl Client {
         let response_body = response.bytes().await?;
 
         if status.is_success() {
-            //println!("response payload {}", String::from_utf8_lossy(&response_body));
+            log::debug!(
+                "response payload {}",
+                String::from_utf8_lossy(&response_body)
+            );
             let parsed_response = if status == http::StatusCode::NO_CONTENT
                 || std::any::TypeId::of::<Out>() == std::any::TypeId::of::<()>()
             {
@@ -617,11 +619,6 @@ impl Client {
             };
             parsed_response.map_err(Error::from)
         } else {
-            /*println!("error status: {:?}, response payload: {}",
-                status,
-                String::from_utf8_lossy(&response_body),
-            );*/
-
             let error = if response_body.is_empty() {
                 anyhow!("code: {}, empty response", status)
             } else {
@@ -689,7 +686,7 @@ impl Client {
             req = req.body(b);
         }
 
-        //println!("Request: {:?}", &req);
+        log::debug!("request: {:?}", &req);
         let response = req.send().await?;
 
         let status = response.status();
@@ -697,7 +694,10 @@ impl Client {
         let response_body = response.bytes().await?;
 
         if status.is_success() {
-            //println!("response payload {}", String::from_utf8_lossy(&response_body));
+            log::debug!(
+                "response payload {}",
+                String::from_utf8_lossy(&response_body)
+            );
             let parsed_response = if status == http::StatusCode::NO_CONTENT
                 || std::any::TypeId::of::<Out>() == std::any::TypeId::of::<()>()
             {
@@ -707,11 +707,6 @@ impl Client {
             };
             parsed_response.map_err(Error::from)
         } else {
-            /*println!("error status: {:?}, response payload: {}",
-                status,
-                String::from_utf8_lossy(&response_body),
-            );*/
-
             let error = if response_body.is_empty() {
                 anyhow!("code: {}, empty response", status)
             } else {
